Package: redatamx
Title: R Interface to 'Redatam' Library
Version: 1.3.0
Authors@R: c(
    person(
      given = "Jaime", 
      family = "Salvador", 
      email = "jaime.salvador@ideasybits.com", 
      role = c("aut", "cre"),
      comment = c(ORCID = "0000-0002-3564-8929")),
    person(
      given = "CELADE",
      role = c("cph")
    )
  )
Maintainer: Jaime Salvador <jaime.salvador@ideasybits.com>
Description: Provides an API to work with 'Redatam' (see <https://redatam.org>) 
  databases in both formats: 'RXDB' (new format) and 'DICX' (old format) and running 
  'Redatam' programs written in 'SPC' language. It's a wrapper around 'Redatam' 
  core and provides functions to open/close a database (redatam_open()/redatam_close()), 
  list entities and variables from the database (redatam_entities(), redatam_variables()) 
  and execute a 'SPC' program and gets the results as data frames 
  (redatam_query(), redatam_run()).
License: GPL (>= 3)
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
NeedsCompilation: yes
LinkingTo: cpp11
SystemRequirements: 'Redatam' runtime engine (see https://redatam.org),
        The dynamic binary library is downloaded from
        <https://redatam-core.s3.us-west-2.amazonaws.com> during the
        build step. Currently supported platforms are Windows, Linux
        and macOS.
Copyright: See COPYRIGHTS for details.
URL: https://ideasybits.github.io/redatamx4r/,
        https://github.com/ideasybits/redatamx4r/
BugReports: https://github.com/ideasybits/redatamx4r/issues
Config/Needs/website: rmarkdown
Packaged: 2026-05-05 21:39:24 UTC; jsalvador
Author: Jaime Salvador [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3564-8929>),
  CELADE [cph]
Repository: CRAN
Date/Publication: 2026-05-06 05:10:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-06 06:59:33 UTC; unix
Archs: redatamx.so.dSYM
