# Generated by roxygen2: do not edit by hand

export(outputs)
export(redatam_close)
export(redatam_entities)
export(redatam_info)
export(redatam_load_plugin)
export(redatam_open)
export(redatam_query)
export(redatam_run)
export(redatam_save)
export(redatam_variables)
export(redatam_version)
exportPattern("^[[:alpha:]]+")
useDynLib(redatamx, .registration = TRUE)
