# Generated by cpp11: do not edit by hand

redatam_create <- function(schema_name, config_name) {
  invisible(.Call(`_redatamx_redatam_create`, schema_name, config_name))
}

redatam_open <- function(dictionary_name) {
  .Call(`_redatamx_redatam_open`, dictionary_name)
}

redatam_save <- function(dic, name) {
  invisible(.Call(`_redatamx_redatam_save`, dic, name))
}

redatam_close <- function(dic) {
  invisible(.Call(`_redatamx_redatam_close`, dic))
}

redatam_entities <- function(dic) {
  .Call(`_redatamx_redatam_entities`, dic)
}

redatam_variables <- function(dic, entity_name) {
  .Call(`_redatamx_redatam_variables`, dic, entity_name)
}

redatam_internal_query <- function(dic, spc) {
  .Call(`_redatamx_redatam_internal_query`, dic, spc)
}

redatam_internal_run <- function(dic, file_name) {
  .Call(`_redatamx_redatam_internal_run`, dic, file_name)
}

redatam_version <- function() {
  .Call(`_redatamx_redatam_version`)
}

redatam_info <- function() {
  .Call(`_redatamx_redatam_info`)
}

redatam_init_ <- function(packageDir) {
  invisible(.Call(`_redatamx_redatam_init_`, packageDir))
}

redatam_destroy_ <- function() {
  invisible(.Call(`_redatamx_redatam_destroy_`))
}

redatam_load_plugin <- function(spc) {
  invisible(.Call(`_redatamx_redatam_load_plugin`, spc))
}
