% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redatam-api.R
\name{redatam_close}
\alias{redatam_close}
\title{Close dictionary}
\usage{
redatam_close(dic)
}
\arguments{
\item{dic}{Dictionary identifier (returned by redatam_open())}
}
\value{
{No return value.}
}
\description{
Close a REDATAM database.
}
\examples{
\dontrun{
dic<-redatam_open("path/to/rxdb")
# run some queries using 'redatam_query' or 'redatam_run'
# close de dictionary
redatam_close(dic);
}
}
\author{
Jaime Salvador
}
